@@ -2,7 +2,7 @@
  *
  *  Connection Manager
  *
- *  Copyright (C) 2007-2008  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2007-2009  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -27,14 +27,13 @@
 #include <unistd.h>
 #include <stdlib.h>
 
+#define CONNMAN_API_SUBJECT_TO_CHANGE
 #include <connman/plugin.h>
 #include <connman/resolver.h>
 #include <connman/log.h>
 
 #include <glib.h>
 
-#define RESOLVCONF "/sbin/resolvconf"
-
 static int resolvconf_append(const char *interface, const char *domain,
 							const char *server)
 {
@@ -51,8 +50,7 @@ static int resolvconf_append(const char *interface, const char *domain,
 
 	DBG("%s", cmd);
 
-	//err = system(cmd);
-	err = 0;
+	err = system(cmd);
 
 	g_free(cmd);
 
@@ -71,8 +69,7 @@ static int resolvconf_remove(const char *interface, const char *domain,
 
 	DBG("%s", cmd);
 
-	//err = system(cmd);
-	err = 0;
+	err = system(cmd);
 
 	g_free(cmd);
 
@@ -97,4 +94,4 @@ static void resolvconf_exit(void)
 }
 
 CONNMAN_PLUGIN_DEFINE(resolvconf, "Name resolver plugin", VERSION,
-					resolvconf_init, resolvconf_exit)
+		CONNMAN_PLUGIN_PRIORITY_DEFAULT, resolvconf_init, resolvconf_exit)
